==> qore-0.9.4.3.tar.bz2: qore-0.9.4.3/docs/library/html/index.js <==
var index =
[
    [ "Introduction to the Qore Library", "index.html#introduction", null ],
    [ "Qore Data", "qore_data.html", [
      [ "Qore Data", "qore_data.html#handling_data", [
        [ "Simple Value Types: QoreBigIntNode, QoreFloatNode, QoreStringNode, DateTimeNode, BinaryNode", "qore_data.html#simple_value_types", null ],
        [ "Unique Value Types: QoreBoolNode, QoreNullNode, QoreNothingNode", "qore_data.html#unique_value_types", null ],
        [ "Container Value Types: QoreHashNode, QoreListNode, QoreObject", "qore_data.html#container_types", null ],
        [ "Object Value Type: QoreObject", "qore_data.html#qoreobject", null ],
        [ "Handling Reference Arguments: ReferenceNode and ReferenceHelper", "qore_data.html#reference_arguments", null ]
      ] ]
    ] ],
    [ "Developing Qore Modules", "qore_modules.html", [
      [ "Qore Module development", "qore_modules.html#module_dev", [
        [ "Module Header Info", "qore_modules.html#module_header", null ],
        [ "Module Functions", "qore_modules.html#module_functions", null ]
      ] ]
    ] ],
    [ "Using Qore with CMake Build System", "qore_cmake.html", [
      [ "Using Qore and CMake", "qore_cmake.html#qore_cmake_about", null ],
      [ "Build Type Handling", "qore_cmake.html#qore_cmake_build_type", null ],
      [ "FIND_PACKAGE Arguments", "qore_cmake.html#qore_cmake_find_package", [
        [ "CMake Qore Variables", "qore_cmake.html#qore_cmake_variables", null ],
        [ "Compiler Defines", "qore_cmake.html#qore_cmake_defines", null ]
      ] ],
      [ "Qore Binary Modules Support for CMake", "qore_cmake.html#qore_cmake_binary_modules", [
        [ "QORE_WRAP_QPP", "qore_cmake.html#QORE_WRAP_QPP", null ],
        [ "QORE_BINARY_MODULE", "qore_cmake.html#QORE_BINARY_MODULE", null ],
        [ "QORE_DIST", "qore_cmake.html#QORE_DIST", null ],
        [ "QORE_CONFIG_INFO", "qore_cmake.html#QORE_CONFIG_INFO", null ],
        [ "Qore Binary Module Example", "qore_cmake.html#qore_cmake_binary_modules_example", null ]
      ] ]
    ] ]
];

==> qore-2.0.0.tar.bz2: qore-2.0.0/docs/library/html/index.js <==
var index =
[
    [ "Introduction to the Qore Library", "index.html#introduction", null ],
    [ "Qore Data", "qore_data.html", [
      [ "Qore Data", "qore_data.html#handling_data", [
        [ "Simple Value Types: QoreStringNode, DateTimeNode, BinaryNode", "qore_data.html#simple_value_types", null ],
        [ "Unique Value Types: QoreNullNode, QoreNothingNode", "qore_data.html#unique_value_types", null ],
        [ "Container Value Types: QoreHashNode, QoreListNode, QoreObject", "qore_data.html#container_types", null ],
        [ "Object Value Type: QoreObject", "qore_data.html#qoreobject", null ],
        [ "Handling Reference Arguments: ReferenceNode and QoreTypeSafeReferenceHelper", "qore_data.html#reference_arguments", null ]
      ] ]
    ] ],
    [ "Developing Qore Modules", "qore_modules.html", [
      [ "Qore Module development", "qore_modules.html#module_dev", [
        [ "Module Header Info", "qore_modules.html#module_header", null ],
        [ "Module Functions", "qore_modules.html#module_functions", null ]
      ] ]
    ] ],
    [ "Using Qore with CMake Build System", "qore_cmake.html", [
      [ "Using Qore and CMake", "qore_cmake.html#qore_cmake_about", null ],
      [ "Build Type Handling", "qore_cmake.html#qore_cmake_build_type", null ],
      [ "FIND_PACKAGE Arguments", "qore_cmake.html#qore_cmake_find_package", [
        [ "CMake Qore Variables", "qore_cmake.html#qore_cmake_variables", null ],
        [ "Compiler Defines", "qore_cmake.html#qore_cmake_defines", null ]
      ] ],
      [ "Qore Binary Modules Support for CMake", "qore_cmake.html#qore_cmake_binary_modules", [
        [ "QORE_WRAP_QPP", "qore_cmake.html#QORE_WRAP_QPP", null ],
        [ "QORE_BINARY_MODULE", "qore_cmake.html#QORE_BINARY_MODULE", null ],
        [ "QORE_DIST", "qore_cmake.html#QORE_DIST", null ],
        [ "QORE_CONFIG_INFO", "qore_cmake.html#QORE_CONFIG_INFO", null ],
        [ "Qore Binary Module Example", "qore_cmake.html#qore_cmake_binary_modules_example", null ]
      ] ]
    ] ]
];
